@@ -403,6 +403,10 @@ def sample(df1, df2, formula_array, family_array, N, I, T, burnin, interval):
         #Formula
         new_dict["formula"] = formula
         
+        if len(formula.split('~')) == 1:
+            print("Formula {} is not a valid formula".format(formula))
+            raise(NameError("Invalid formula"))
+            
         covs = formula.split("~")[1].split('+')
         #All covariates (not response)
         new_dict["covs"] = covs        
